@@ -46,6 +46,7 @@ from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import AwsClustersTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import AwsClustersGrpcTransport
 from .transports.grpc_asyncio import AwsClustersGrpcAsyncIOTransport
+from .transports.rest import AwsClustersRestTransport
 
 
 class AwsClustersClientMeta(type):
@@ -59,6 +60,7 @@ class AwsClustersClientMeta(type):
     _transport_registry = OrderedDict()  # type: Dict[str, Type[AwsClustersTransport]]
     _transport_registry["grpc"] = AwsClustersGrpcTransport
     _transport_registry["grpc_asyncio"] = AwsClustersGrpcAsyncIOTransport
+    _transport_registry["rest"] = AwsClustersRestTransport
 
     def get_transport_class(
         cls,
@@ -401,6 +403,9 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
             transport (Union[str, AwsClustersTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
+                NOTE: "rest" transport functionality is currently in a
+                beta state (preview). We welcome your feedback via an
+                issue in this library's source repository.
             client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
@@ -502,6 +507,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_create_aws_cluster():
@@ -511,11 +523,11 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 # Initialize request argument(s)
                 aws_cluster = gke_multicloud_v1.AwsCluster()
                 aws_cluster.networking.vpc_id = "vpc_id_value"
-                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value_1', 'pod_address_cidr_blocks_value_2']
-                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value_1', 'service_address_cidr_blocks_value_2']
+                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value1', 'pod_address_cidr_blocks_value2']
+                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value1', 'service_address_cidr_blocks_value2']
                 aws_cluster.aws_region = "aws_region_value"
                 aws_cluster.control_plane.version = "version_value"
-                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value_1', 'subnet_ids_value_2']
+                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value1', 'subnet_ids_value2']
                 aws_cluster.control_plane.iam_instance_profile = "iam_instance_profile_value"
                 aws_cluster.control_plane.database_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
@@ -664,6 +676,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_update_aws_cluster():
@@ -673,11 +692,11 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 # Initialize request argument(s)
                 aws_cluster = gke_multicloud_v1.AwsCluster()
                 aws_cluster.networking.vpc_id = "vpc_id_value"
-                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value_1', 'pod_address_cidr_blocks_value_2']
-                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value_1', 'service_address_cidr_blocks_value_2']
+                aws_cluster.networking.pod_address_cidr_blocks = ['pod_address_cidr_blocks_value1', 'pod_address_cidr_blocks_value2']
+                aws_cluster.networking.service_address_cidr_blocks = ['service_address_cidr_blocks_value1', 'service_address_cidr_blocks_value2']
                 aws_cluster.aws_region = "aws_region_value"
                 aws_cluster.control_plane.version = "version_value"
-                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value_1', 'subnet_ids_value_2']
+                aws_cluster.control_plane.subnet_ids = ['subnet_ids_value1', 'subnet_ids_value2']
                 aws_cluster.control_plane.iam_instance_profile = "iam_instance_profile_value"
                 aws_cluster.control_plane.database_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
@@ -823,6 +842,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_get_aws_cluster():
@@ -925,6 +951,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_list_aws_clusters():
@@ -1050,6 +1083,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_delete_aws_cluster():
@@ -1111,9 +1151,6 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1178,6 +1215,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_generate_aws_access_token():
@@ -1266,6 +1310,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_create_aws_node_pool():
@@ -1424,6 +1475,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_update_aws_node_pool():
@@ -1575,6 +1633,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_get_aws_node_pool():
@@ -1679,6 +1744,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_list_aws_node_pools():
@@ -1802,6 +1874,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_delete_aws_node_pool():
@@ -1863,9 +1942,6 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
         # Quick check: If we got a request object, we should *not* have
@@ -1932,6 +2008,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import gke_multicloud_v1
 
             def sample_get_aws_server_config():
