@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import AzureClustersTransport
 from .grpc import AzureClustersGrpcTransport
 from .grpc_asyncio import AzureClustersGrpcAsyncIOTransport
+from .rest import AzureClustersRestTransport
+from .rest import AzureClustersRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[AzureClustersTransport]]
 _transport_registry["grpc"] = AzureClustersGrpcTransport
 _transport_registry["grpc_asyncio"] = AzureClustersGrpcAsyncIOTransport
+_transport_registry["rest"] = AzureClustersRestTransport
 
 __all__ = (
     "AzureClustersTransport",
     "AzureClustersGrpcTransport",
     "AzureClustersGrpcAsyncIOTransport",
+    "AzureClustersRestTransport",
+    "AzureClustersRestInterceptor",
 )
